.shipping-information {
    --pp-accent: #6a3f66;
    --pp-accent-soft: #efe8f0;
    --pp-border: #d7d7dc;
    --pp-text: #2f2f35;
    --pp-muted: #6f6f79;

    margin-bottom: 30px;
    padding: 22px;
    background: #f7f7f9;
    border: 1px solid var(--pp-border);
    border-radius: 6px;
}

.shipping-information .field-title {
    font-size: 18px;
    font-weight: 700;
    margin-bottom: 20px;
    padding-bottom: 10px;
    border-bottom: 1px solid var(--pp-border);
    color: var(--pp-accent);
}

.shipping-information .field {
    margin-bottom: 18px;
}

.shipping-information .field label {
    font-weight: 600;
    color: var(--pp-text);
}

.shipping-information .field .label {
    margin-bottom: 6px;
}

.shipping-information .field .control {
    margin-top: 6px;
}

.shipping-information .control textarea {
    width: 100%;
    padding: 10px 12px;
    border: 1px solid #c7c7cf;
    border-radius: 4px;
    background: #fff;
}

.shipping-information .control input[type="text"] {
    width: 100%;
    padding: 10px 12px;
    border: 1px solid #c7c7cf;
    border-radius: 4px;
    background: #fff;
}

.shipping-information .control input[type="text"]:focus,
.shipping-information .control textarea:focus {
    border-color: var(--pp-accent);
    box-shadow: 0 0 0 2px rgba(106, 63, 102, 0.14);
}

.portalpeople-calendar-only {
    position: relative;
    display: block;
}

.portalpeople-inline-datepicker {
    margin-top: 10px;
    margin-left: auto;
    margin-right: auto;
    max-width: 332px;
}

.portalpeople-calendar-only-input {
    position: absolute;
    top: 0;
    left: 0;
    width: 1px;
    height: 1px;
    opacity: 0;
    pointer-events: none;
}

.portalpeople-inline-datepicker .ui-datepicker {
    width: 100%;
    box-sizing: border-box;
    padding: 10px;
    border: 1px solid #d2d2d9;
    border-radius: 6px;
    background: #fff;
    box-shadow: none;
}

.portalpeople-inline-datepicker .ui-datepicker-header {
    border: 0;
    background: transparent;
    color: var(--pp-accent);
    font-weight: 700;
}

.portalpeople-inline-datepicker .ui-datepicker-title {
    font-weight: 700;
}

.portalpeople-inline-datepicker .ui-datepicker .ui-datepicker-prev,
.portalpeople-inline-datepicker .ui-datepicker .ui-datepicker-next {
    color: var(--pp-accent);
}

.portalpeople-inline-datepicker .ui-datepicker th {
    color: var(--pp-muted);
    font-size: 12px;
    font-weight: 700;
}

.portalpeople-inline-datepicker .ui-state-default {
    border: 0;
    background: transparent;
    text-align: center;
    border-radius: 4px;
    color: var(--pp-text);
    padding: 0.45em;
}

.portalpeople-inline-datepicker .ui-state-hover {
    background: var(--pp-accent-soft);
    color: var(--pp-accent);
}

.portalpeople-inline-datepicker .ui-datepicker-current-day .ui-state-default {
    background: var(--pp-accent);
    color: #fff;
    border-radius: 4px;
}

.portalpeople-inline-datepicker .ui-datepicker-today .ui-state-default {
    box-shadow: inset 0 0 0 1px var(--pp-accent);
}

.portalpeople-calendar-value {
    font-size: 13px;
    color: var(--pp-accent);
    display: block;
    margin-bottom: 6px;
    font-weight: 700;
}

@media (max-width: 640px) {
    .shipping-information {
        padding: 16px;
    }

    .portalpeople-inline-datepicker {
        max-width: 100%;
    }
}

/* Ensure visibility on checkout */
.opc-wrapper .shipping-information {
    display: block !important;
    visibility: visible !important;
}
